==> amazcart_v4.0.zip: amazcart_v4.0/resources/lang/default/payment_gatways.php <==
<?php return [
    'paypal' => 'Paypal',
    'paypal_configuration' => 'Paypal Configuration',
    'paypal_client_secret' => 'Paypal Client Secret Key',
    'paypal_client_id' => 'Paypal Client ID',
    'stripe' => 'Stripe',
    'stripe_configuration' => 'Stripe Configuration',
    'stripe_key' => 'Stripe Key',
    'stripe_secret_key' => 'Stripe Secret Key',
    'stripe_user_name' => 'Stripe User Name',
    'paystack_configuration' => 'Paystack Configuration',
    'paystack_key' => 'Paystack Key',
    'paystack_secret_key' => 'Paystack Secret Key',
    'paystack_merchant_email' => 'Paystack Merchant Email',
    'paystack' => 'Paystack',
    'razor_secret_key' => 'Razor Pay Secret Key',
    'razor_key' => 'razor_key',
    'razorpay' => 'RazorPay',
    'instamojo_payment' =>'Instamojo payment',
    'razorpay_configuration' => 'RazorPay Configuration',
    'paystack_payment_url' => 'Paystack Payment URL',
    'bank_payment' => 'Bank Payment',
    'bank_configuration' => 'Bank Configuration',
    'account_holder' => 'Account Holder',
    'account_number' => 'Account Number',
    'bank_name' => 'Bank Name',
    'branch_name' => 'Branch Name',
    'paytm' => 'PayTM',
    'paytm_configuration' => 'Paytm Configuration',
    'paytm_environment' => 'Paytm Environment',
    'merchant_id' => 'Merchant Id',
    'merchant_key' => 'Merchant Key',
    'merchant_website' => 'Merchant Website',
    'paytm_channel' => 'Paytm Channel',
    'paytm_industry_type' => 'Paytm Industry Type',
    'instamojo' => 'Instamojo',
    'instamojo_configuration' => 'Instamojo Configuration',
    'api_key' => 'Api Key',
    'auth_token' => 'Auth Token',
    'instamojo_url' => 'Instamojo Url',
    'midtrans' => 'Midtrans',
    'midtrans_configuration' => 'Midtrans Configuration',
    'merchant_server_key' => 'Merchant Server Key',
    'is_production_mode' => 'Is Producttion Mode',
    'merchant_client_key' => 'Merchant Client Key',
    'sandbox_environment' => 'Sandbox Environment',
    'production_environment' => 'Production Environment',
    'payumoney' => 'PayUmoney',
    'payumoney_configuration' => 'Payumoney Configuration',
    'payu_money_mode' => 'PayU Money Mode',
    'payumoney_key' => 'PayUmoney Key',
    'payumoney_salt' => 'PayUmoney Salt',
    'payumoney_auth' => 'PayUmoney Auth',
    'jazzcash' => 'JazzCash',
    'jazzcash_configuration' => 'JazzCash Configuration',
    'password' => 'Password',
    'salt_id' => 'Salt Id',
    'live_url' => 'Live Url',
    'google_pay' => 'Google Pay',
    'google_pay_configuration' => 'Google Pay Configuration',
    'gateway_name' => 'Gateway Name',
    'merchant_name' => 'Merchant Name',
    'flutter_wave_payment' => 'Flutter Wave Payment',
    'flutter_wave_payment_configuration' => 'Flutter Wave Payment Configuration',
    'public_key' => 'Public Key',
    'secret_key' => 'Secret Key',
    'secret_hash' => 'Secret Hash',
    'paddle' => 'Paddle',
    'paddle_payment_configuration' => 'Paddle Payment Configuration',
    'environment' => 'Environment',
    'vendor_id' => 'Vendor Id',
    'vendor_auth_code' => 'Vendor Auth Code',
    'test' => 'Test',
    'live' => 'Live',
    'sandbox' => 'Sandbox',
    'gateway_logo' => 'Gateway Logo',
    'recharge_successfully' => 'Recharge successful!',
    'payment_details' => 'Payment Details',
    'name_on_card' => 'Name on Card',
    'card_number' => 'Card Number',
    'cvc' => 'CVC',
    'expiration_month' => 'Expiration Month',
    'expiration_year' => 'Expiration Year',
    'please_correct_the_errors_and_try_again' => 'Please correct the errors and try again.',
    'pay_now_100' => 'Pay Now ($100)',
    'bank_account_info' => 'Bank account info',
    'bkash' => 'bkash',
    'bkash_configuration' => 'Bkash Configuration',
    'app_key' => 'App Key',
    'app_secret' => 'App Secret',
    'username' => 'Username',
    'ssl_commerz' => 'Ssl Commerz',
    'sslcommerz_configuration' => 'SslCommerz Configuration',
    'api_domain_url' => 'Api Domain URL',
    'store_id' => 'Store ID',
    'store_password' => 'Store Password',
    'mercado_pago_configuration' => 'Mercado Pago Configuration',
    'tabby_configuration' => 'Tabby Configuration',
    'ccavenue_configuration' => 'CCAvenue Configuration',
    'mercado_pago' => 'Mercado Pago',
    'card_expiration_date' => 'Card Expiration Date',
    'cardholder_name' => 'Cardholder Name',
    'cardholder_email' => 'Cardholder Email',
    'security_code' => 'Security Code',
    'issuer' => 'Issuer',
    'identification_type' => 'Identification Type',
    'identification_number' => 'Identification Number',
    'installments' => 'Installments',
    'access_token' => 'Access Token',
    'cheque_slip' => 'Cheque slip',
    'Global Configuration' => 'Global Configuration',
    'cash_on_delivery' => 'Cash On Delivery',
    'wallet' => 'Wallet',
    'paystack_payment_url' => 'PAYSTACK PAYMENT URL',
    'callback_url' => 'Callback URL',
    'sandbox_url' => 'Sandbox URL',
    'webhook_url' => 'Webhook URL',
    'success_url' => 'Success URL',
    'failed_url' => 'Failed URL',
    'payment_amount' => 'Payment Amount',
    'global_configuration' => 'Global Configuration',
    'amount' => 'Amount',
    'tabby' => 'Tabby',
    'ccavenue' => 'CCAvenue',
    'api_secret' => 'API Secret',
    'cca_key' => 'CCAvenue Key',
    'cca_access_code' => 'CCAvenue Access Code',
    'cca_merchant_id' => 'CCAvenue Merchant ID',
    "Fees" => "Fees",
    "Tabby Payment Fees" => "Tabby Payment Fees",
    "of Total Amount" => "of Total Amount",
    "Tabby Fee" => "Tabby Fee",
    "Tabby Frontend Text" => "Tabby Frontend Text",
    "Tabby Gateway Only Support AED Currency" => "Tabby Gateway Only Support AED Currency",
    "4 intereset-free Payments" => "4 intereset-free Payments",
    "Tabby Merchant Code" => "Tabby Merchant Code",
    "clickpay" => "Clickpay",
    "Clickpay" => "Clickpay",
    "clickpay_configuration" => "Clickpay Configuration",
    'profile_id' => "Profile ID",
    'api_server_key' => "Api Server Key",
    'api_client_key' => "Api Client Key",
    'sdk_server_key' => "SDK Server Key",
    'sdk_client_key' => "SDK Client Key",
    'environment' => "Environment",
];

==> amazcart_v4.4.zip: amazcart_v4.4/resources/lang/default/payment_gatways.php <==
<?php return [
    'paypal' => 'Paypal',
    'paypal_configuration' => 'Paypal Configuration',
    'paypal_client_secret' => 'Paypal Client Secret Key',
    'paypal_client_id' => 'Paypal Client ID',
    'stripe' => 'Stripe',
    'stripe_configuration' => 'Stripe Configuration',
    'stripe_key' => 'Stripe Key',
    'stripe_secret_key' => 'Stripe Secret Key',
    'stripe_user_name' => 'Stripe User Name',
    'paystack_configuration' => 'Paystack Configuration',
    'paystack_key' => 'Paystack Key',
    'paystack_secret_key' => 'Paystack Secret Key',
    'paystack_merchant_email' => 'Paystack Merchant Email',
    'paystack' => 'Paystack',
    'razor_secret_key' => 'Razor Pay Secret Key',
    'razor_key' => 'razor_key',
    'razorpay' => 'RazorPay',
    'instamojo_payment' =>'Instamojo payment',
    'razorpay_configuration' => 'RazorPay Configuration',
    'paystack_payment_url' => 'Paystack Payment URL',
    'bank_payment' => 'Bank Payment',
    'bank_configuration' => 'Bank Configuration',
    'account_holder' => 'Account Holder',
    'account_number' => 'Account Number',
    'bank_name' => 'Bank Name',
    'branch_name' => 'Branch Name',
    'paytm' => 'PayTM',
    'paytm_configuration' => 'Paytm Configuration',
    'paytm_environment' => 'Paytm Environment',
    'merchant_id' => 'Merchant Id',
    'merchant_key' => 'Merchant Key',
    'merchant_website' => 'Merchant Website',
    'paytm_channel' => 'Paytm Channel',
    'paytm_industry_type' => 'Paytm Industry Type',
    'instamojo' => 'Instamojo',
    'instamojo_configuration' => 'Instamojo Configuration',
    'api_key' => 'Api Key',
    'auth_token' => 'Auth Token',
    'instamojo_url' => 'Instamojo Url',
    'midtrans' => 'Midtrans',
    'midtrans_configuration' => 'Midtrans Configuration',
    'merchant_server_key' => 'Merchant Server Key',
    'is_production_mode' => 'Is Producttion Mode',
    'merchant_client_key' => 'Merchant Client Key',
    'sandbox_environment' => 'Sandbox Environment',
    'production_environment' => 'Production Environment',
    'payumoney' => 'PayUmoney',
    'payumoney_configuration' => 'Payumoney Configuration',
    'payu_money_mode' => 'PayU Money Mode',
    'payumoney_key' => 'PayUmoney Key',
    'payumoney_salt' => 'PayUmoney Salt',
    'payumoney_auth' => 'PayUmoney Auth',
    'jazzcash' => 'JazzCash',
    'jazzcash_configuration' => 'JazzCash Configuration',
    'password' => 'Password',
    'salt_id' => 'Salt Id',
    'live_url' => 'Live Url',
    'google_pay' => 'Google Pay',
    'google_pay_configuration' => 'Google Pay Configuration',
    'gateway_name' => 'Gateway Name',
    'merchant_name' => 'Merchant Name',
    'flutter_wave_payment' => 'Flutter Wave Payment',
    'flutter_wave_payment_configuration' => 'Flutter Wave Payment Configuration',
    'public_key' => 'Public Key',
    'secret_key' => 'Secret Key',
    'secret_hash' => 'Secret Hash',
    'paddle' => 'Paddle',
    'paddle_payment_configuration' => 'Paddle Payment Configuration',
    'environment' => 'Environment',
    'vendor_id' => 'Vendor Id',
    'vendor_auth_code' => 'Vendor Auth Code',
    'test' => 'Test',
    'live' => 'Live',
    'sandbox' => 'Sandbox',
    'gateway_logo' => 'Gateway Logo',
    'recharge_successfully' => 'Recharge successful!',
    'payment_details' => 'Payment Details',
    'name_on_card' => 'Name on Card',
    'card_number' => 'Card Number',
    'cvc' => 'CVC',
    'expiration_month' => 'Expiration Month',
    'expiration_year' => 'Expiration Year',
    'please_correct_the_errors_and_try_again' => 'Please correct the errors and try again.',
    'pay_now_100' => 'Pay Now ($100)',
    'bank_account_info' => 'Bank account info',
    'bkash' => 'bkash',
    'bkash_configuration' => 'Bkash Configuration',
    'app_key' => 'App Key',
    'app_secret' => 'App Secret',
    'username' => 'Username',
    'ssl_commerz' => 'Ssl Commerz',
    'sslcommerz_configuration' => 'SslCommerz Configuration',
    'api_domain_url' => 'Api Domain URL',
    'store_id' => 'Store ID',
    'store_password' => 'Store Password',
    'mercado_pago_configuration' => 'Mercado Pago Configuration',
    'tabby_configuration' => 'Tabby Configuration',
    'ccavenue_configuration' => 'CCAvenue Configuration',
    'mercado_pago' => 'Mercado Pago',
    'card_expiration_date' => 'Card Expiration Date',
    'cardholder_name' => 'Cardholder Name',
    'cardholder_email' => 'Cardholder Email',
    'security_code' => 'Security Code',
    'issuer' => 'Issuer',
    'identification_type' => 'Identification Type',
    'identification_number' => 'Identification Number',
    'installments' => 'Installments',
    'access_token' => 'Access Token',
    'cheque_slip' => 'Cheque slip',
    'Global Configuration' => 'Global Configuration',
    'cash_on_delivery' => 'Cash On Delivery',
    'wallet' => 'Wallet',
    'callback_url' => 'Callback URL',
    'sandbox_url' => 'Sandbox URL',
    'webhook_url' => 'Webhook URL',
    'success_url' => 'Success URL',
    'failed_url' => 'Failed URL',
    'payment_amount' => 'Payment Amount',
    'global_configuration' => 'Global Configuration',
    'amount' => 'Amount',
    'tabby' => 'Tabby',
    'ccavenue' => 'CCAvenue',
    'api_secret' => 'API Secret',
    'cca_key' => 'CCAvenue Key',
    'cca_access_code' => 'CCAvenue Access Code',
    'cca_merchant_id' => 'CCAvenue Merchant ID',
    "Fees" => "Fees",
    "Tabby Payment Fees" => "Tabby Payment Fees",
    "of Total Amount" => "of Total Amount",
    "Tabby Fee" => "Tabby Fee",
    "Tabby Frontend Text" => "Tabby Frontend Text",
    "Tabby Gateway Only Support AED Currency" => "Tabby Gateway Only Support AED Currency",
    "4 intereset-free Payments" => "4 intereset-free Payments",
    "Tabby Merchant Code" => "Tabby Merchant Code",
    "clickpay" => "Clickpay",
    "Clickpay" => "Clickpay",
    "clickpay_configuration" => "Clickpay Configuration",
    'profile_id' => "Profile ID",
    'api_server_key' => "Api Server Key",
    'api_client_key' => "Api Client Key",
    'sdk_server_key' => "SDK Server Key",
    'sdk_client_key' => "SDK Client Key",
    "gateway_not_active" => "Payment gateway not active",
];
